/* $Id: SEPsesam.java,v 1.4 2014/11/05 07:58:28 kha Exp $
 *
 * The SEP sesam Plugin coded as a java source code file, interpreted
 * as a beanshell script.
 * 
 */

package SEP;


import bsh2java.Plugin;
import bsh2java.log;
import definitions.messages;
import java.io.File;
import relink.MSlink;
import utils.files;
import utils.is;

/**
 *
 * @author Nuno Brito, 15th of March 2014 in Darmstadt, Germany.
 */
public class SEPsesam extends Plugin{

   String title = "SEP sesam client";
    
   @Override
   public void startup(){
      // add a hook to run a given method when a log message occurs
      addHook(messages.Adding_plugin_Win7PEx86, "processHook");
   }
    
   /**
    * Test method that should run when adding plugins to boot disk project
    */
   void processHook() {
      log.write(is.INFO, "Adding %1", title);

      // assign the folders and files that will be used
      File sourceFolder = new File(thisFolder, "files");

      // import the registry settings
      File sourceRegistry = new File(thisFolder, "settings.reg");
      winpe.hive.softwareHive.importReg(sourceRegistry.getAbsolutePath());

      // copy the files to the new destination
      utils.files.copyFolder(sourceFolder, winpe.targetWimFolder);
    
      insertInstallSesamToStartnet();
      addDesktopLinks();
   }
   
   void insertInstallSesamToStartnet() {
      // get the startnet batch file
      File batchFile = new File(winpe.targetWinSysFolder, "startnet.cmd");
      // don't continue if the file was not found
      if(batchFile.exists() == false){
          log.write(is.ERROR, "Failed to find batch file at %1",
                  batchFile.getAbsolutePath());
          return;
      }
      // now read the contents of the batch file
      String content = utils.files.readAsString(batchFile);

      // get the installSesam batch file
      File sesamBatchFile = new File(thisFolder, "files\\Program Files\\SEPsesam\\installSesam.cmd");
      if(sesamBatchFile.exists() == false){
          log.write(is.ERROR, "Failed to find SEP sesam batch file at %1",
                  sesamBatchFile.getAbsolutePath());
          return;
      }
      // now read the contents of the sesam batch file
      String sesamContent = utils.files.readAsString(sesamBatchFile);
      // add the content of the installSesam.cmd to the startnet.cmd
      String newContent = content.concat("\r\n" + sesamContent);
      // write everything back into the file
      files.SaveStringToFile(batchFile, newContent); 
      // all done
      log.write(is.COMPLETED, "Added installSesam.cmd to startnet.cmd");
   }
    
   void addDesktopLinks() {
      File folderDesktop = new File(winpe.targetWinSysFolder, "config/systemprofile/DeskTop");
      File installSesamLnk = new File (folderDesktop, "InstallSesam.lnk");
      File loadDriversLnk = new File (folderDesktop, "LoadDrivers.lnk");
      File mapNetworkDriveLnk = new File (folderDesktop, "MapNetworkDrive.lnk");
      
      MSlink sesamLink = new MSlink ();
      sesamLink.setTarget ("x:\\Program Files\\SEPsesam\\installSesam.cmd", false);
      sesamLink.setComment ("Install Sesam");
      sesamLink.setArguments("");
      //sesamLink.setIcon ("x:\\WINDOWS\\system32\\shell32.dll");
      //sesamLink.setIconIndex(7);
      sesamLink.setIcon ("x:\\Program Files\\SEPsesam\\bin\\sesam\\sesam.ico");
      sesamLink.setWorkingDir("x:\\Program Files\\SEPsesam\\bin\\sesam");
      sesamLink.save (installSesamLnk); 
      log.write(is.COMPLETED, "Added installSesam.lnk to Desktop");

      MSlink driverLink = new MSlink ();
      driverLink.setTarget ("x:\\Program Files\\SEPsesam\\loadDrivers.cmd", false);
      driverLink.setComment ("Load Drivers");
      driverLink.setArguments("");
      driverLink.setIcon ("x:\\WINDOWS\\system32\\shell32.dll");
      //driverLink.setIconIndex(250);
      driverLink.setIconIndex(11);
      driverLink.setWorkingDir("x:\\customDrivers");
      driverLink.save (loadDriversLnk); 
      log.write(is.COMPLETED, "Added loadDrivers.lnk to Desktop");
      
      MSlink mapNetworkDrive = new MSlink ();
      mapNetworkDrive.setTarget ("x:\\Program Files\\SEPsesam\\mapNetworkDrive.cmd", false);
      mapNetworkDrive.setComment ("Map Network Drive");
      mapNetworkDrive.setArguments("");
      mapNetworkDrive.setIcon ("x:\\WINDOWS\\system32\\shell32.dll");
      mapNetworkDrive.setIconIndex(9);
      mapNetworkDrive.save (mapNetworkDriveLnk); 
      log.write(is.COMPLETED, "Added mapNetworkDrive.lnk to Desktop");
   }
}
