set version=$Id: sbc_oracle_rman.cmd,v 1.1 2007/10/18 08:28:24 miraculix Exp $
@echo off

rem *** sbc_oracle_rman.cmd
rem *** 
rem *** This file builds and runs rman scripts.
rem *** It is called via command line from the Sesam2000 Server (GUI)
rem *** This file has to be placed in ..\bin\sesam directory of the client on which the Oracle DB is running
rem *** The Syntax is explained at the end of the file.
rem *** 
rem *** It is recommended that the full rman funtionality is given. 
rem *** There for please read the documentation which is delivered with the sm_sob_interface kit
rem ***
rem *** Known limitations (not implemented yet):
rem *** No checking for Sesam-Server Daemons, Sesam Job, Sesam Drive, and Trace-level
rem *** No checking if connect strings work with the running Oracle DB (only checking for "@" in the strings)
rem *** No restore availability via script, only by rman !!! 


echo *******************************************************************
echo * SESAM Oracle RMAN Client for Windows NT/2K/XP                   *
echo * %version% *
echo *******************************************************************

echo.
set my_name=%0
set mode=%1
set level=%2
set connect_target=%3
set connect_rman=%4
set sesam_server=%5
set task=%6
set drive=%7
set pool=%8
set trace=%9
shift
set table_space=%9

echo %my_name% %mode% %level% %connect_target% %connect_rman% %sesam_server% %task% %drive% %pool% %trace% %table_space%
echo.

set cmd_file=%TEMP%\%task%_cmd.rma
echo cmd file %cmd_file%

set ini_file=%task%.bat
echo Check if optional init file %ini_file% exists
if exist %ini_file% call %ini_file%


rem *** Check, if ORACLE_HOME and TEMP-Directory are set

if "%ORACLE_HOME%"=="" ( 
  echo.
  echo !!! WARNING: ORACLE_HOME not set. rman execution with PATH !!!
  echo.
)

if "%TEMP%"=="" echo ERROR: TEMP Directory not set
if "%TEMP%"=="" goto exit

rem *** Checking for correct sbc_oracle_rman syntax

if "%mode%"=="b" echo Mode =                             Backup
if "%mode%"=="r" echo Mode =                             Restore
if not "%mode%"=="b" if not "%mode%"=="r" echo ERROR: Mode = %mode% unknown, must be b=backup or r=restore
if not "%mode%"=="b" if not "%mode%"=="r" goto usage  

if "%level%"=="full" echo Level =                            Full 
if "%level%"=="copy" echo Level =                            Copy 
if "%level%"=="diff" echo Level =                            Differential
if "%level%"=="incr" echo Level =                            Incremental 
if "%level%"=="arch" echo Level =                            Archive Logs
if "%level%"=="ardl" echo Level = 			     Archive Logs (delete after Backup)   
if not "%level%"=="copy" if not "%level%"=="full" if not "%level%"=="diff" if not "%level%"=="incr" if not "%level%"=="arch" if not "%level%"=="ardl" echo ERROR: Level = %level% unknown, must be copy, full, diff, incr, arch or ardl 
if not "%level%"=="copy" if not "%level%"=="full" if not "%level%"=="diff" if not "%level%"=="incr" if not "%level%"=="arch" if not "%level%"=="ardl" goto usage

echo Target Connect String  =    %connect_target%
echo Catalog Connect String =    %connect_rman%

echo.

rem *** Checking for Sesam Server Connection (simple ping). 
rem *** NOT a secure test for checking Sesam Daemons on Server
rem *** Will implemented in following versions of sbc_oracle_rman for Windows

if "%sesam_server%"=="" echo ERROR: Please enter Name of Sesam Server
if "%sesam_server%"=="" goto usage
echo checking connection to host: %sesam_server%
echo.
ping %sesam_server%>NUL
if %ERRORLEVEL% EQU 0 echo Sesam Server =                     %sesam_server% reachable
if %ERRORLEVEL% EQU 1 echo ERROR: Sesam Server = %sesam_server% not reachable, please check connection, DNS, hosts-file
if %ERRORLEVEL% EQU 1 goto end

rem *** No checks for Sesam Job, drive and trace level
rem *** Error msg will come from rman and sbtio.log

echo Sesam Job =                        %task%
echo Accessing Drive Number =           %drive%
echo Sesam Media Pool =                 %pool%
echo Trace Level is =                   %trace%

rem *** Checking for tablespace value. If no value is given, will perform full target database

if "%table_space%"=="" echo Processing FULL DATABASE (no Tablespace selected)
if not "%table_space%"=="" echo Accessing Tablespace = %table_space%
if "%table_space%"=="" set TABLESPACE=( database )
if not "%table_space%"=="" set TABLESPACE= ( tablespace %table_space% )
if "%mode%"=="b" goto backup_environment
if "%mode%"=="r" goto restore_environment

goto end

:backup_environment

rem *** Building BACKUP format stamps for rman

if "%level%"=="full" set STAMP=dft%%t_s%%s_p%%p
if "%level%"=="full" goto bck_build_full
if "%level%"=="copy" set STAMP=dct%%t_s%%s_p%%p
if "%level%"=="copy" goto bck_build_copy
if "%level%"=="incr" set STAMP=dit%%t_s%%s_p%%p
if "%level%"=="incr" goto bck_build_incr
if "%level%"=="diff" set STAMP=ddt%%t_s%%s_p%%p
if "%level%"=="diff" goto bck_build_diff
if "%level%"=="arch" set STAMP=dat%%t_s%%s_p%%p
if "%level%"=="arch" goto bck_build_arch
if "%level%"=="ardl" set STAMP=dat%%t_s%%s_p%%p
if "%level%"=="ardl" goto bck_build_ardl

:restore_environment

rem *** Building RESTORE format stamps for rman

if "%level%"=="full" set STAMP=dft%%t_s%%s_p%%p
if "%level%"=="full" goto rst_build_full
if "%level%"=="copy" set STAMP=dct%%t_s%%s_p%%P
if "%level%"=="copy" goto rst_build_copy
if "%level%"=="incr" set STAMP=dit%%t_s%%s_p%%p
if "%level%"=="incr" goto rst_build_incr
if "%level%"=="diff" set STAMP=ddt%%t_s%%s_p%%p
if "%level%"=="diff" goto rst_build_diff
if "%level%"=="arch" set STAMP=dat%%t_s%%s_p%%p
if "%level%"=="arch" goto rst_build_arch

rem *** Building RMAN BACKUP Scripts for different levels

:bck_build_copy

echo run{ > %cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%)";>>%cmd_file%
echo backup full filesperset 10 format "%STAMP%" %TABLESPACE%; >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo.
goto run_rman

:bck_build_full

echo run{ > %cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%)";>>%cmd_file%
echo backup incremental level 0 filesperset 10 format "%STAMP%" %TABLESPACE%; >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo.
goto run_rman

:bck_build_diff

echo run{ > %cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%)";>>%cmd_file%
echo backup incremental level 1 cumulative filesperset 10 format "%STAMP%" %TABLESPACE%; >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo.
goto run_rman

:bck_build_incr

echo run{ > %cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%)";>>%cmd_file%
echo backup incremental level 1 filesperset 10 format "%STAMP%" %TABLESPACE%; >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo.
goto run_rman

:bck_build_arch

echo run{ > %cmd_file%
echo sql "alter system archive log current"; >>%cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%)";>>%cmd_file%
echo backup filesperset 10 format "%STAMP%" ( archivelog all skip inaccessible ); >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo. 
goto run_rman

:bck_build_ardl

echo run{ > %cmd_file%
echo sql "alter system archive log current"; >>%cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%)";>>%cmd_file%
echo backup filesperset 10 format "%STAMP%" ( archivelog all delete input skip inaccessible channel t1 ); >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo. 
goto run_rman

:rst_build_full

echo run{ > %cmd_file%
echo allocate channel t1 type "sbt_tape" parms "ENV=(SESAM_SERVER=%sesam_server%,SESAM_JOB=%task%,SESAM_DRIVE=%drive%,SESAM_POOL=%pool%,SOB_TRACE=%trace%,SOB_LOGFILE=c:\temp\sob.log)";>>%cmd_file%
echo restore database; >>%cmd_file%
echo recover database; >>%cmd_file%
echo release channel t1;>>%cmd_file%
echo } >> %cmd_file%

echo.
echo RMAN Command File complete...running RMAN with given values
echo Please wait...
echo. 
goto run_rman


:usage

rem *** Required usage of sbc_oracle_rman for Windows 

echo.
echo Usage: 
echo "%my_name% b|r <Level> <TARGET ConnectString> <RCVCAT ConnectString> <Sesam Server> <Sesam Job> <Sesam Drive> <Sesam Pool> <Trace Level> [<Tablespace>]"
echo.
echo Arguments:
echo Mode               b=backup, r=restore
echo Level              copy, full, diff, incr, arch, ardl
echo Target Connect     Connect String for Target DB (internal/oracle@ORCL)
echo Rcvcat Connect     Connect String for Catalog DB (rman/rman@RCVCAT or nocatalog)
echo Sesam Server       Name of Sesam Server
echo Sesam Job          Name of existing Sesam Job for this client
echo Sesam Drive        Number of Target Sesam Drive
echo Sesam Pool         Sesam Media Pool
echo Trace Level        Level of Tracing to sbtio.log (0 - 3)
echo Tablespace         Name of Tablespace for beeing backed up
goto end


:run_rman

echo Start:
time /t
if "%connect_rman%" EQU "nocatalog" goto run_rman_nocatalog
echo call %ORACLE_HOME%\bin\rman target %connect_target% rcvcat %connect_rman% cmdfile %cmd_file% 
call %ORACLE_HOME%\bin\rman target %connect_target% rcvcat %connect_rman% cmdfile %cmd_file% 

if %ERRORLEVEL% NEQ 0 goto error

goto end


:run_rman_nocatalog
echo call %ORACLE_HOME%\bin\rman target %connect_target% %connect_rman% cmdfile %cmd_file% 
call %ORACLE_HOME%\bin\rman target %connect_target% %connect_rman% cmdfile %cmd_file% 

if %ERRORLEVEL% NEQ 0 goto error

goto end


REM  *****  postprocessing of sbc_oracle_rman 

:error

echo ERROR: RMAN exited with error

:exit

exit /b 2


:end
set STAMP=
rem TODO
rem del %TEMP%.\%task%.tmp
rem del %cmd_file%
echo.

