Write-Host "$((Get-Date).ToString()): Start rescan of disks"
Write "rescan" | diskpart

Write-Host "$((Get-Date).ToString()): Enabling automount"
Write "automount enable" | diskpart

Write-Host "Search for SEP sesam install directory."
$binsesam=(Get-ItemProperty "HKLM:\SOFTWARE\SEP Elektronik GmbH\sesam").SM_BIN_SESAM

Write-Host "Change current directory to $binsesam"
Set-Location $binsesam


Write-Host "$((Get-Date).ToString()): Get partitions before bringing new disks on line."
$partbefore=(./sm_client.exe dir / 2>$1 | Select-String "^`"[A-Z]:`".*Fixed Drive") -Replace "`" dt .*","" -Replace "`"",""
if ( $partbefore -eq $null )
{
    Write-Host "$((Get-Date).ToString()): No partition was found, which must not be possible. Exiting."
    Write "STATUS=ERROR MSG="
    exit 1
}

Write-Host "$((Get-Date).ToString()): Found following partitions:"
Write $partbefore

Write-Host "$((Get-Date).ToString()): Waiting 2 seconds to finish sync of disks."
Sleep 2

Write-Host "$((Get-Date).ToString()): Get list of disks and model. Just hard drive should be recognized."
$listdisk=$(Get-WmiObject -Class Win32_DiskDrive | Where-Object  {$_.mediatype -eq "Fixed hard disk media"} | Select-Object index,model)

if ( $listdisk -eq $null )
{
	Write-Host "$((Get-Date).ToString()): Array `"listdisk`" is empty. Exiting."
	exit 1
}

Write-Host "$((Get-Date).ToString()): Following disks were found on system:"
Write $listdisk

# Just get drive number
$diskarray=$($listdisk | Select-Object index)


Write-Host "$((Get-Date).ToString()): Starting loop to mark each disk as on line"
$count=0
while($count -lt $diskarray.Count) # Loop for all disks
{
    Write-Host "$((Get-Date).ToString()): Mark disk $($diskarray[$count].index) as on line"
    Write "select disk $($diskarray[$count].index)" "online disk" | diskpart
    $count++
}

Write-Host "$((Get-Date).ToString()): Wait 5 additional seconds after bringing disks on line."
Sleep 5

$partafter=(./sm_client.exe dir / 2>$1 | Select-String "^`"[A-Z]:`".*Fixed Drive") -Replace "`" dt .*","" -Replace "`"",""
if ( $partafter -eq $null )
{
    Write-Host "$((Get-Date).ToString()): No partition was found, which must not be possible. Exiting."
    Write "STATUS=ERROR MSG="
    exit 1
}

if ( $partbefore.Count -eq $partafter.Count )
{
    Write-Host "$((Get-Date).ToString()): No new partition has been added to system. Exiting."
    Write "STATUS=ERROR MSG="
    exit 1
}

Write-Host "$((Get-Date).ToString()): Found following partitions after bringing new disk(s) on line:"
Write $partafter

$countbefore=0
$countafter=0
$allnewpartitions="STATUS=SUCCESS MSG=Drives:"

Write-Host "$((Get-Date).ToString()): Starting compare of new partitions, which were added."
while ( $countafter -lt $partafter.Count )
{
    Write-Host "$((Get-Date).ToString()): Checking drive letter $($partafter[$countafter]) of new query."
    $countbefore=0
    $isnew=$true
    while( $countbefore -lt $partbefore.Count )
    {
        Write-Host "$((Get-Date).ToString()): Checking against drive letter $($partbefore[$countbefore]) of old query."
        if ( "$($partafter[$countafter])" -eq "$($partbefore[$countbefore])" )
        {
            Write-Host "$((Get-Date).ToString()): Found equal drive letter. Checking next drive letter."
            $isnew=$false # Set false, in case current drive letter already existed before disk(s) got on line
            $countbefore = $partbefore.Count # Set counter to exit loop at next run
        }
        $countbefore++
    }
    
    if ( $isnew -eq $true ) # Has a new drive letter been added?
    {
        Write-Host "$((Get-Date).ToString()): Found new drive letter $($partafter[$countafter]). Adding it to list."
        $allnewpartitions+=" $($partafter[$countafter])"
    }
    $countafter++
}

Write $allnewpartitions

exit
# SIG # Begin signature block
# MIIZAgYJKoZIhvcNAQcCoIIY8zCCGO8CAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUWuEklNy/wzu6B0NF3wxusdc1
# twCgghP6MIID7jCCA1egAwIBAgIQfpPr+3zGTlnqS5p31Ab8OzANBgkqhkiG9w0B
# AQUFADCBizELMAkGA1UEBhMCWkExFTATBgNVBAgTDFdlc3Rlcm4gQ2FwZTEUMBIG
# A1UEBxMLRHVyYmFudmlsbGUxDzANBgNVBAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhh
# d3RlIENlcnRpZmljYXRpb24xHzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3RhbXBpbmcg
# Q0EwHhcNMTIxMjIxMDAwMDAwWhcNMjAxMjMwMjM1OTU5WjBeMQswCQYDVQQGEwJV
# UzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9yYXRpb24xMDAuBgNVBAMTJ1N5bWFu
# dGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EgLSBHMjCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBALGss0lUS5ccEgrYJXmRIlcqb9y4JsRDc2vCvy5Q
# WvsUwnaOQwElQ7Sh4kX06Ld7w3TMIte0lAAC903tv7S3RCRrzV9FO9FEzkMScxeC
# i2m0K8uZHqxyGyZNcR+xMd37UWECU6aq9UksBXhFpS+JzueZ5/6M4lc/PcaS3Er4
# ezPkeQr78HWIQZz/xQNRmarXbJ+TaYdlKYOFwmAUxMjJOxTawIHwHw103pIiq8r3
# +3R8J+b3Sht/p8OeLa6K6qbmqicWfWH3mHERvOJQoUvlXfrlDqcsn6plINPYlujI
# fKVOSET/GeJEB5IL12iEgF1qeGRFzWBGflTBE3zFefHJwXECAwEAAaOB+jCB9zAd
# BgNVHQ4EFgQUX5r1blzMzHSa1N197z/b7EyALt0wMgYIKwYBBQUHAQEEJjAkMCIG
# CCsGAQUFBzABhhZodHRwOi8vb2NzcC50aGF3dGUuY29tMBIGA1UdEwEB/wQIMAYB
# Af8CAQAwPwYDVR0fBDgwNjA0oDKgMIYuaHR0cDovL2NybC50aGF3dGUuY29tL1Ro
# YXd0ZVRpbWVzdGFtcGluZ0NBLmNybDATBgNVHSUEDDAKBggrBgEFBQcDCDAOBgNV
# HQ8BAf8EBAMCAQYwKAYDVR0RBCEwH6QdMBsxGTAXBgNVBAMTEFRpbWVTdGFtcC0y
# MDQ4LTEwDQYJKoZIhvcNAQEFBQADgYEAAwmbj3nvf1kwqu9otfrjCR27T4IGXTdf
# plKfFo3qHJIJRG71betYfDDo+WmNI3MLEm9Hqa45EfgqsZuwGsOO61mWAK3ODE2y
# 0DGmCFwqevzieh1XTKhlGOl5QGIllm7HxzdqgyEIjkHq3dlXPx13SYcqFgZepjhq
# IhKjURmDfrYwggSjMIIDi6ADAgECAhAOz/Q4yP6/NW4E2GqYGxpQMA0GCSqGSIb3
# DQEBBQUAMF4xCzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBDb3Jwb3Jh
# dGlvbjEwMC4GA1UEAxMnU3ltYW50ZWMgVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBD
# QSAtIEcyMB4XDTEyMTAxODAwMDAwMFoXDTIwMTIyOTIzNTk1OVowYjELMAkGA1UE
# BhMCVVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMTQwMgYDVQQDEytT
# eW1hbnRlYyBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIFNpZ25lciAtIEc0MIIBIjAN
# BgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAomMLOUS4uyOnREm7Dv+h8GEKU5Ow
# mNutLA9KxW7/hjxTVQ8VzgQ/K/2plpbZvmF5C1vJTIZ25eBDSyKV7sIrQ8Gf2Gi0
# jkBP7oU4uRHFI/JkWPAVMm9OV6GuiKQC1yoezUvh3WPVF4kyW7BemVqonShQDhfu
# ltthO0VRHc8SVguSR/yrrvZmPUescHLnkudfzRC5xINklBm9JYDh6NIipdC6Anqh
# d5NbZcPuF3S8QYYq3AhMjJKMkS2ed0QfaNaodHfbDlsyi1aLM73ZY8hJnTrFxeoz
# C9Lxoxv0i77Zs1eLO94Ep3oisiSuLsdwxb5OgyYI+wu9qU+ZCOEQKHKqzQIDAQAB
# o4IBVzCCAVMwDAYDVR0TAQH/BAIwADAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDAO
# BgNVHQ8BAf8EBAMCB4AwcwYIKwYBBQUHAQEEZzBlMCoGCCsGAQUFBzABhh5odHRw
# Oi8vdHMtb2NzcC53cy5zeW1hbnRlYy5jb20wNwYIKwYBBQUHMAKGK2h0dHA6Ly90
# cy1haWEud3Muc3ltYW50ZWMuY29tL3Rzcy1jYS1nMi5jZXIwPAYDVR0fBDUwMzAx
# oC+gLYYraHR0cDovL3RzLWNybC53cy5zeW1hbnRlYy5jb20vdHNzLWNhLWcyLmNy
# bDAoBgNVHREEITAfpB0wGzEZMBcGA1UEAxMQVGltZVN0YW1wLTIwNDgtMjAdBgNV
# HQ4EFgQURsZpow5KFB7VTNpSYxc/Xja8DeYwHwYDVR0jBBgwFoAUX5r1blzMzHSa
# 1N197z/b7EyALt0wDQYJKoZIhvcNAQEFBQADggEBAHg7tJEqAEzwj2IwN3ijhCcH
# bxiy3iXcoNSUA6qGTiWfmkADHN3O43nLIWgG2rYytG2/9CwmYzPkSWRtDebDZw73
# BaQ1bHyJFsbpst+y6d0gxnEPzZV03LZc3r03H0N45ni1zSgEIKOq8UvEiCmRDoDR
# EfzdXHZuT14ORUZBbg2w6jiasTraCXEQ/Bx5tIB7rGn0/Zy2DBYr8X9bCT2bW+IW
# yhOBbQAuOA2oKY8s4bL0WqkBrxWcLC9JG9siu8P+eJRRw4axgohd8D20UaF5Mysu
# e7ncIAkTcetqGVvP6KUwVyyJST+5z3/Jvz4iaGNTmr1pdKzFHTx/kuDDvBzYBHUw
# ggVPMIIEN6ADAgECAhBFJdVMzQeBwEJaHN/ndDHmMA0GCSqGSIb3DQEBBQUAMIG0
# MQswCQYDVQQGEwJVUzEXMBUGA1UEChMOVmVyaVNpZ24sIEluYy4xHzAdBgNVBAsT
# FlZlcmlTaWduIFRydXN0IE5ldHdvcmsxOzA5BgNVBAsTMlRlcm1zIG9mIHVzZSBh
# dCBodHRwczovL3d3dy52ZXJpc2lnbi5jb20vcnBhIChjKTEwMS4wLAYDVQQDEyVW
# ZXJpU2lnbiBDbGFzcyAzIENvZGUgU2lnbmluZyAyMDEwIENBMB4XDTExMTEyNTAw
# MDAwMFoXDTE0MTEyNDIzNTk1OVowgZIxCzAJBgNVBAYTAkRFMRAwDgYDVQQIEwdC
# YXZhcmlhMQ8wDQYDVQQHEwZXZXlhcm4xDzANBgNVBAoUBlNFUCBBRzE+MDwGA1UE
# CxM1RGlnaXRhbCBJRCBDbGFzcyAzIC0gTWljcm9zb2Z0IFNvZnR3YXJlIFZhbGlk
# YXRpb24gdjIxDzANBgNVBAMUBlNFUCBBRzCCASIwDQYJKoZIhvcNAQEBBQADggEP
# ADCCAQoCggEBAKPk8sFkobQAgR7xfCW3B7oNFbaer+Bc2MLh7Tctb+jJHBuZtczR
# D0UUsBLb8TRVnujZSxuRQSnK9vB/uaI3gy42d/+XqiwcZ92l+wcQB6tuS2FTAb1z
# d+f2irj+ewHZCrxSaWyxQLuu8TQbxhMCDvh+75UAfkJby1haO6XXqXDp28DEDYTl
# J34g3yAqmMX2pscHpnk1mDO087Sf22PZ/capDI2kPO08EijfiOPDfLxoO/gOVb9a
# iGNFU0xKoWITJuZirKwS0v2prPK2YCm0bAmcoRlnxjUfLY+rMMmK73WLTuoJrGtg
# JBHuARLK2QgbpFeo0N4ZuJPo78XiYPIAjuECAwEAAaOCAXswggF3MAkGA1UdEwQC
# MAAwDgYDVR0PAQH/BAQDAgeAMEAGA1UdHwQ5MDcwNaAzoDGGL2h0dHA6Ly9jc2Mz
# LTIwMTAtY3JsLnZlcmlzaWduLmNvbS9DU0MzLTIwMTAuY3JsMEQGA1UdIAQ9MDsw
# OQYLYIZIAYb4RQEHFwMwKjAoBggrBgEFBQcCARYcaHR0cHM6Ly93d3cudmVyaXNp
# Z24uY29tL3JwYTATBgNVHSUEDDAKBggrBgEFBQcDAzBxBggrBgEFBQcBAQRlMGMw
# JAYIKwYBBQUHMAGGGGh0dHA6Ly9vY3NwLnZlcmlzaWduLmNvbTA7BggrBgEFBQcw
# AoYvaHR0cDovL2NzYzMtMjAxMC1haWEudmVyaXNpZ24uY29tL0NTQzMtMjAxMC5j
# ZXIwHwYDVR0jBBgwFoAUz5mp6nsm9EvJjo/X8AUm7+PSp50wEQYJYIZIAYb4QgEB
# BAQDAgQQMBYGCisGAQQBgjcCARsECDAGAQEAAQH/MA0GCSqGSIb3DQEBBQUAA4IB
# AQDtgoI/IZxnwNdt+NbmQ8oinCBqJjsU8h4kqgI3MOEkabBZb+yZIPM5cWWnce57
# 5WtZH21wG/Gl5oaNpu8D4FgvnhHDWm9gykLCWJPUfucH8LY4xXE5eGLPQHMvslNe
# omxeJPhx0iTgiMEhxcMUcWDc8KVcC6xsS2uwezqEEv+f8ehI/Q+I8Cbw+xiifNEK
# GovEw/sbeVXgYk70MbVVA8LGBv5ZXnBTK6SLEezXCLkFkEsU8NV6Xc8oplxgDF5p
# Bh8yeZvUoPDsb0eNxwS93y4YMRQrMurCwwfXcqyisEvX+J0JsvB2VNNo4LIqgDv1
# tP5zBnSVmlFZo9eRxtRSAiQoMIIGCjCCBPKgAwIBAgIQUgDlqiVW/BqG7ZbJ1Esz
# xzANBgkqhkiG9w0BAQUFADCByjELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlT
# aWduLCBJbmMuMR8wHQYDVQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTowOAYD
# VQQLEzEoYykgMjAwNiBWZXJpU2lnbiwgSW5jLiAtIEZvciBhdXRob3JpemVkIHVz
# ZSBvbmx5MUUwQwYDVQQDEzxWZXJpU2lnbiBDbGFzcyAzIFB1YmxpYyBQcmltYXJ5
# IENlcnRpZmljYXRpb24gQXV0aG9yaXR5IC0gRzUwHhcNMTAwMjA4MDAwMDAwWhcN
# MjAwMjA3MjM1OTU5WjCBtDELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWdu
# LCBJbmMuMR8wHQYDVQQLExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQL
# EzJUZXJtcyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAo
# YykxMDEuMCwGA1UEAxMlVmVyaVNpZ24gQ2xhc3MgMyBDb2RlIFNpZ25pbmcgMjAx
# MCBDQTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAPUjS16l14q7MunU
# V/fv5Mcmfq0ZmP6onX2U9jZrENd1gTB/BGh/yyt1Hs0dCIzfaZSnN6Oce4DgmeHu
# N01fzjsU7obU0PUnNbwlCzinjGOdF6MIpauw+81qYoJM1SHaG9nx44Q7iipPhVuQ
# AU/Jp3YQfycDfL6ufn3B3fkFvBtInGnnwKQ8PEEAPt+W5cXklHHWVQHHACZKQDy1
# oSapDKdtgI6QJXvPvz8c6y+W+uWHd8a1VrJ6O1QwUxvfYjT/HtH0WpMoheVMF05+
# W/2kk5l/383vpHXv7xX2R+f4GXLYLjQaprSnTH69u08MPVfxMNamNo7WgHbXGS6l
# zX40LYkCAwEAAaOCAf4wggH6MBIGA1UdEwEB/wQIMAYBAf8CAQAwcAYDVR0gBGkw
# ZzBlBgtghkgBhvhFAQcXAzBWMCgGCCsGAQUFBwIBFhxodHRwczovL3d3dy52ZXJp
# c2lnbi5jb20vY3BzMCoGCCsGAQUFBwICMB4aHGh0dHBzOi8vd3d3LnZlcmlzaWdu
# LmNvbS9ycGEwDgYDVR0PAQH/BAQDAgEGMG0GCCsGAQUFBwEMBGEwX6FdoFswWTBX
# MFUWCWltYWdlL2dpZjAhMB8wBwYFKw4DAhoEFI/l0xqGrI2Oa8PPgGrUSBgsexku
# MCUWI2h0dHA6Ly9sb2dvLnZlcmlzaWduLmNvbS92c2xvZ28uZ2lmMDQGA1UdHwQt
# MCswKaAnoCWGI2h0dHA6Ly9jcmwudmVyaXNpZ24uY29tL3BjYTMtZzUuY3JsMDQG
# CCsGAQUFBwEBBCgwJjAkBggrBgEFBQcwAYYYaHR0cDovL29jc3AudmVyaXNpZ24u
# Y29tMB0GA1UdJQQWMBQGCCsGAQUFBwMCBggrBgEFBQcDAzAoBgNVHREEITAfpB0w
# GzEZMBcGA1UEAxMQVmVyaVNpZ25NUEtJLTItODAdBgNVHQ4EFgQUz5mp6nsm9EvJ
# jo/X8AUm7+PSp50wHwYDVR0jBBgwFoAUf9Nlp8Ld7LvwMAnzQzn6Aq8zMTMwDQYJ
# KoZIhvcNAQEFBQADggEBAFYi5jSkxGHLSLkBrVaoZA/ZjJHEu8wM5a16oCJ/30c4
# Si1s0X9xGnzscKmx8E/kDwxT+hVe/nSYSSSFgSYckRRHsExjjLuhNNTGRegNhSZz
# A9CpjGRt3HGS5kUFYBVZUTn8WBRr/tSk7XlrCAxBcuc3IgYJviPpP0SaHulhncyx
# kFz8PdKNrEI9ZTbUtD1AKI+bEM8jJsxLIMuQH12MTDTKPNjlN9ZvpSC9NOsm2a4N
# 58Wa96G0IZEzb4boWLslfHQOWP51G2M/zjF8m48blp7FU3aEW5ytkfqs7ZO6Xcgh
# U8KCU2OvEg1QhxEbPVRSloosnD2SGgiaBS7Hk6VIkdMxggRyMIIEbgIBATCByTCB
# tDELMAkGA1UEBhMCVVMxFzAVBgNVBAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQL
# ExZWZXJpU2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJtcyBvZiB1c2Ug
# YXQgaHR0cHM6Ly93d3cudmVyaXNpZ24uY29tL3JwYSAoYykxMDEuMCwGA1UEAxMl
# VmVyaVNpZ24gQ2xhc3MgMyBDb2RlIFNpZ25pbmcgMjAxMCBDQQIQRSXVTM0HgcBC
# Whzf53Qx5jAJBgUrDgMCGgUAoHAwEAYKKwYBBAGCNwIBDDECMAAwGQYJKoZIhvcN
# AQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUw
# IwYJKoZIhvcNAQkEMRYEFG0eKC354B9jCZoGLbg2dfY+i5OkMA0GCSqGSIb3DQEB
# AQUABIIBAKCti6s7QUUiHbAg5kTI2xqhp2VzsqGvvR6BrZCv4yJLVAQmN7DTSFOh
# /u6QFeuxybxpa7E/8pHuA0ZDU+tNf5BUgzN6R800OctX2T35AyIbMKs6WevjMf89
# fmL0/7w0pnEoHF8gsBK1vu4aelGdxdVU37ctx73983AoOuhPS1liJs3E8Y4CsJTr
# YIZ2gsgyYDa36H81+ElIJ9Mm4pddFMfltkwmKwk4SUMsPsiYUQbdpMbR2L1KvD7z
# GJWumSn2Mq6ZL5c7yp11LTGGPdMpwamZZvNOuX30i/SZ/PDEMixSBlxR3TwKZU/s
# iZ+UoRm79+NLKwNgiG9+vSgcKVGSBBahggILMIICBwYJKoZIhvcNAQkGMYIB+DCC
# AfQCAQEwcjBeMQswCQYDVQQGEwJVUzEdMBsGA1UEChMUU3ltYW50ZWMgQ29ycG9y
# YXRpb24xMDAuBgNVBAMTJ1N5bWFudGVjIFRpbWUgU3RhbXBpbmcgU2VydmljZXMg
# Q0EgLSBHMgIQDs/0OMj+vzVuBNhqmBsaUDAJBgUrDgMCGgUAoF0wGAYJKoZIhvcN
# AQkDMQsGCSqGSIb3DQEHATAcBgkqhkiG9w0BCQUxDxcNMTQxMTA1MTYwMjM5WjAj
# BgkqhkiG9w0BCQQxFgQUpKfG1zmZKzeITCiitsrfpHxrLJUwDQYJKoZIhvcNAQEB
# BQAEggEASKwpN+1k61BosoLVFZZfHuiRsD8R45VC1cIx2yYJzMM9+2L69RdY55rk
# YOmdSxfYMkCuV8wI2NAl8TzeBuCNhYydQFiYWEKAD6aw/bBpHfzwaTzjjJMb/l2z
# lzz5zfzYk262W0Y67IS/XaGEYv9EfO8iEphLfv0OXDCPkeWmjGAF4B02JuJhX3kd
# sI/0UkEo68J5qczDULNWolk59XvLfh93LPEosWRVwSH7l7fl0ke1TX7PjhvD30WR
# nkx85YCBGjSdHfOPiMBg69Es5gjSOa8/FSVd9q7svvqUL1Gvx9Jl1dAXUO3kiwih
# L4rOS+8s0s8s9H0uz2uD13l/rXwi2Q==
# SIG # End signature block
